@@ -18,10 +18,14 @@ namespace ARTICLE
 
         int m_gotonum_seen; // 前回見ていた場所へのジャンプ用
 
+        bool m_set_history; // update_finish() で履歴を登録する
+
         bool m_show_instdialog;
 
         bool m_playsound;
 
+        bool m_show_closedialog;
+
       public:
         ArticleViewMain( const std::string& url );
         ~ArticleViewMain();
