@@ -7,6 +7,7 @@
 #include "boardview.h"
 
 #include "skeleton/msgdiag.h"
+#include "skeleton/filediag.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/miscgtk.h"
@@ -21,6 +22,7 @@
 #include "control/controlutil.h"
 
 #include "command.h"
+#include "cache.h"
 #include "session.h"
 #include "sharedbuffer.h"
 #include "global.h"
@@ -65,8 +67,10 @@ enum{
     COL_MARKVAL_NEWTHREAD_HOUR,  // 新スレ( CONFIG::get_newthread_hour 時間以内 )
     COL_MARKVAL_NEWTHREAD,       // 前回の板一覧読み込み時から新しく出来たスレ
     COL_MARKVAL_CACHED,          // キャッシュあり、新着無し
+    COL_MARKVAL_BROKEN_SUBJECT,  // キャッシュあり、新着無しだが subject.txt が壊れている可能性がある
     COL_MARKVAL_UPDATED,         // キャッシュあり、新着有り
     COL_MARKVAL_BKMARKED,        // ブックマークされている、新着無し
+    COL_MARKVAL_BKMARKED_BROKEN_SUBJECT, // ブックマークされている、新着無しだが subject.txt が壊れている可能性がある
     COL_MARKVAL_BKMARKED_UPDATED // ブックマークされている、新着有り
 };
 
@@ -112,8 +116,8 @@ BoardViewBase::BoardViewBase( const std::string& url )
       m_previous_col( COL_NUM_COL ),
       m_sortmode( SORTMODE_ASCEND ),
       m_previous_sortmode( false ),
-      m_updated( false ),
-      m_loading( false )
+      m_loading( false ),
+      m_enable_menuslot( true )
 {
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
@@ -162,7 +166,7 @@ BoardViewBase::BoardViewBase( const std::string& url )
     m_treeview.sig_key_release().connect( sigc::mem_fun(*this, &BoardViewBase::slot_key_release ) );
     m_treeview.sig_scroll_event().connect( sigc::mem_fun(*this, &BoardViewBase::slot_scroll_event ) );
     m_treeview.signal_drag_data_get().connect( sigc::mem_fun(*this, &BoardViewBase::slot_drag_data_get ) );
-    
+    m_treeview.sig_dropped_uri_list().connect( sigc::mem_fun(*this, &BoardViewBase::slot_dropped_url_list ) );
 
     // ポップアップメニューの設定
     // アクショングループを作ってUIマネージャに登録
@@ -181,13 +185,17 @@ BoardViewBase::BoardViewBase( const std::string& url )
     action_group()->add( Gtk::Action::create( "Delete_Menu", "Delete" ) );
     action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する(_D)" ), sigc::mem_fun( *this, &BoardViewBase::slot_delete_logs ) );
     action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く(_O)" ), sigc::mem_fun( *this, &BoardViewBase::open_selected_rows ) );
-    action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー(_C)" ), sigc::mem_fun( *this, &BoardViewBase::slot_copy_url ) );
-    action_group()->add( Gtk::Action::create( "CopyTitleURL", "タイトルとURLをコピー(_U)" ), sigc::mem_fun( *this, &BoardViewBase::slot_copy_title_url ) );
-    action_group()->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く(_W)" ), sigc::mem_fun( *this, &BoardViewBase::slot_open_browser ) );
+    action_group()->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL + std::string( "(_U)" ) ), sigc::mem_fun( *this, &BoardViewBase::slot_copy_url ) );
+    action_group()->add( Gtk::Action::create( "CopyTitleURL", ITEM_NAME_COPY_TITLE_URL + std::string( "(_L)" ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_copy_title_url ) );
+    action_group()->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER + std::string( "(_W)" ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_open_browser ) );
     action_group()->add( Gtk::Action::create( "AboneThread", "スレをあぼ〜んする(_N)" ), sigc::mem_fun( *this, &BoardViewBase::slot_abone_thread ) );
-    action_group()->add( Gtk::Action::create( "PreferenceArticle", "スレのプロパティ(_I)..." ), sigc::mem_fun( *this, &BoardViewBase::slot_preferences_article ) );
-    action_group()->add( Gtk::Action::create( "Preference", "板のプロパティ(_P)..." ), sigc::mem_fun( *this, &BoardViewBase::show_preference ) );
-    action_group()->add( Gtk::Action::create( "SaveDat", "datファイルを保存(_S)..." ), sigc::mem_fun( *this, &BoardViewBase::slot_save_dat ) );
+    action_group()->add( Gtk::Action::create( "PreferenceArticle", ITEM_NAME_PREF_THREAD + std::string( "(_P)..." ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_preferences_article ) );
+    action_group()->add( Gtk::Action::create( "PreferenceBoard", "板のプロパティ(_O)..." ), sigc::mem_fun( *this, &BoardViewBase::show_preference ) );
+    action_group()->add( Gtk::Action::create( "SaveDat", ITEM_NAME_SAVE_DAT + std::string( "(_S)..." ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_save_dat ) );
 
     ui_manager() = Gtk::UIManager::create();    
     ui_manager()->insert_action_group( action_group() );
@@ -216,7 +224,7 @@ BoardViewBase::BoardViewBase( const std::string& url )
     "</menu>"
     "<separator/>"
     "<menuitem action='PreferenceArticle'/>"
-    "<menuitem action='Preference'/>"
+    "<menuitem action='PreferenceBoard'/>"
     "</popup>"
 
 
@@ -227,6 +235,8 @@ BoardViewBase::BoardViewBase( const std::string& url )
     "<menuitem action='SetBookMark'/>"
     "<menuitem action='UnsetBookMark'/>"
     "<separator/>"
+    "<menuitem action='SaveDat'/>"
+    "<separator/>"
     "<menuitem action='Favorite_Article'/>"
     "<separator/>"
     "<menuitem action='AboneThread'/>"
@@ -274,7 +284,7 @@ BoardViewBase::~BoardViewBase()
 #ifdef _DEBUG    
     std::cout << "BoardViewBase::~BoardViewBase : " << get_url() << std::endl;
 #endif
-    DBTREE::board_save_info( get_url_board() );
+
     save_column_width();
 }
 
@@ -293,20 +303,17 @@ const int BoardViewBase::get_icon( const std::string& iconname )
     if( iconname == "default" ) id = ICON::BOARD;
     if( iconname == "loading" ) id = ICON::LOADING;
     if( iconname == "loading_stop" ) id = ICON::LOADING_STOP;
+    if( iconname == "update" ) id = ICON::BOARD_UPDATE;  // 更新チェックしで更新があった場合
     if( iconname == "updated" ) id = ICON::BOARD_UPDATED;
 
+#ifdef _DEBUG
+    std::cout << "BoardViewBase::get_icon : " << iconname << " url = " << get_url() << std::endl;
+#endif
+
     return id;
 }
 
 
-// 更新した
-const bool BoardViewBase::is_updated()
-{
-    const int code = DBTREE::board_code( get_url_board() );
-    return ( ( code == HTTP_OK || code == HTTP_PARTIAL_CONTENT ) && m_updated );
-}
-
-
 //
 // コピー用URL(メインウィンドウのURLバーなどに表示する)
 //
@@ -316,6 +323,23 @@ const std::string BoardViewBase::url_for_copy()
 }
 
 
+//
+// url から row を取得
+//
+Gtk::TreeModel::Row BoardViewBase::get_row_from_url( const std::string& url )
+{
+    Gtk::TreeModel::Children child = m_liststore->children();
+    Gtk::TreeModel::Children::iterator it;
+    for( it = child.begin() ; it != child.end() ; ++it ){
+
+        Gtk::TreeModel::Row row = *( it );
+        Glib::ustring id_dat = row[ m_columns.m_col_id_dat ];
+        if( url.find( id_dat ) != std::string::npos ) return row;
+    }
+
+    return Gtk::TreeModel::Row();
+}
+
 
 //
 // 列項目の更新
@@ -326,7 +350,7 @@ void BoardViewBase::update_columns()
 
     int num = 0;
     for(;;){
-        const int item = SESSION::get_item_board( num );
+        const int item = SESSION::get_item_board_col( num );
         if( item == ITEM_END ) break;
         switch( item ){
             case ITEM_MARK: APPEND_COLUMN( m_col_mark, ITEM_NAME_MARK, m_columns.m_col_mark ); break;
@@ -648,13 +672,25 @@ void BoardViewBase::slot_col_clicked( const int col )
     else if( m_sortmode == SORTMODE_ASCEND ) m_sortmode = SORTMODE_DESCEND;
     else if( m_sortmode == SORTMODE_MARK1 ) m_sortmode = SORTMODE_MARK2;
     else if( m_sortmode == SORTMODE_MARK2 ) m_sortmode = SORTMODE_MARK3;
-    else if( m_sortmode == SORTMODE_MARK3 ) m_sortmode = SORTMODE_MARK1;
+    else if( m_sortmode == SORTMODE_MARK3 ) m_sortmode = SORTMODE_MARK4;
+    else if( m_sortmode == SORTMODE_MARK4 ) m_sortmode = SORTMODE_MARK1;
+
+    if( m_col == COL_MARK ){
+        std::string info;
+        if( m_sortmode == SORTMODE_MARK1 ) info = "モード 1";
+        if( m_sortmode == SORTMODE_MARK2 ) info = "モード 2";
+        if( m_sortmode == SORTMODE_MARK3 ) info = "モード 3";
+        if( m_sortmode == SORTMODE_MARK4 ) info = "モード 4";
+        CORE::core_set_command( "set_info", "", info );
+    }
+
+/*  そろそろ消しても良い?  問題があれば戻す
 
     // 旧バージョンとの互換性のため
     if( m_col == COL_MARK ){
         if( m_sortmode == SORTMODE_DESCEND || m_sortmode == SORTMODE_ASCEND ) m_sortmode = SORTMODE_MARK1;
     }
-
+*/
     save_sort_columns();
     exec_sort();
     focus_view();
@@ -701,12 +737,33 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
             if( sortmode == SORTMODE_MARK2 ){ // 新着をキャッシュの上に
 
                 if( num_a == COL_MARKVAL_NEWTHREAD
-                    && ( num_b != COL_MARKVAL_NEWTHREAD && num_b != COL_MARKVAL_BKMARKED_UPDATED && num_b != COL_MARKVAL_BKMARKED ) ){
+                    && ( num_b != COL_MARKVAL_NEWTHREAD && num_b != COL_MARKVAL_BKMARKED_UPDATED 
+                         && num_b != COL_MARKVAL_BKMARKED_BROKEN_SUBJECT && num_b != COL_MARKVAL_BKMARKED ) ){
                     num_a = DOWN; // 下で ret *= -1 しているので UP と DOWNを逆にする
                     num_b = UP;
                 }
                 else if( num_b == COL_MARKVAL_NEWTHREAD
-                         && ( num_a != COL_MARKVAL_NEWTHREAD && num_a != COL_MARKVAL_BKMARKED_UPDATED && num_a != COL_MARKVAL_BKMARKED ) ){
+                         && ( num_a != COL_MARKVAL_NEWTHREAD && num_a != COL_MARKVAL_BKMARKED_UPDATED 
+                             && num_a != COL_MARKVAL_BKMARKED_BROKEN_SUBJECT && num_a != COL_MARKVAL_BKMARKED ) ){
+                    num_a = UP; // 下で ret *= -1 しているので UP と DOWNを逆にする
+                    num_b = DOWN;
+                }
+            }
+            else if( sortmode == SORTMODE_MARK3 ){ // 新着を一番上に
+
+                if( num_a == COL_MARKVAL_NEWTHREAD && num_b != COL_MARKVAL_NEWTHREAD ){
+                    num_a = DOWN; // 下で ret *= -1 しているので UP と DOWNを逆にする
+                    num_b = UP;
+                }
+                else if( num_b == COL_MARKVAL_NEWTHREAD && num_a != COL_MARKVAL_NEWTHREAD  ){
+                    num_a = UP; // 下で ret *= -1 しているので UP と DOWNを逆にする
+                    num_b = DOWN;
+                }
+                else if( num_a == COL_MARKVAL_NEWTHREAD_HOUR && num_b != COL_MARKVAL_NEWTHREAD_HOUR ){
+                    num_a = DOWN; // 下で ret *= -1 しているので UP と DOWNを逆にする
+                    num_b = UP;
+                }
+                else if( num_b == COL_MARKVAL_NEWTHREAD_HOUR && num_a != COL_MARKVAL_NEWTHREAD_HOUR ){
                     num_a = UP; // 下で ret *= -1 しているので UP と DOWNを逆にする
                     num_b = DOWN;
                 }
@@ -768,7 +825,7 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
         else if( num_a > num_b ) ret = COL_B_UP;
 
         if( sortmode == SORTMODE_DESCEND ) ret *= -1;
-        if( sortmode == SORTMODE_MARK1 || sortmode == SORTMODE_MARK2 ) ret *= -1;
+        if( sortmode == SORTMODE_MARK1 || sortmode == SORTMODE_MARK2 || sortmode == SORTMODE_MARK3 ) ret *= -1;
     }
 
     // 0より大きい方を優先
@@ -813,6 +870,8 @@ const bool BoardViewBase::set_command( const std::string& command, const std::st
 {
     if( command == "update_columns" ) update_columns();
 
+    else if( command == "draw_bg_articles" ) draw_bg_articles();
+
     return true;
 }
 
@@ -847,6 +906,8 @@ void BoardViewBase::show_view()
     std::cout << "BoardViewBase::show_view " << get_url() << std::endl;
 #endif
 
+    if( is_loading() ) return;
+
     // DBに登録されてない
     if( get_url_board().empty() ){
         set_status( "invalid URL" );
@@ -864,6 +925,9 @@ void BoardViewBase::show_view()
     m_last_access_time = DBTREE::board_last_access_time( get_url_board() );
     m_loading = true;
     
+    // オートリロードのカウンタを0にする
+    reset_autoreload_counter();
+
     // download 開始
     // 終わったら update_view() が呼ばれる
     DBTREE::board_download_subject( get_url_board(), get_url() );
@@ -904,7 +968,6 @@ void BoardViewBase::relayout()
 //
 void BoardViewBase::update_view_impl( std::list< DBTREE::ArticleBase* >& list_subject )
 {
-    m_updated = false;
     m_loading = false;
 
 #ifdef _DEBUG
@@ -922,44 +985,28 @@ void BoardViewBase::update_view_impl( std::list< DBTREE::ArticleBase* >& list_su
     // 自動ソート抑制
     UNSORTED_COLUMN();
 
-    int id = 1;
+    m_id = 0;
     if( list_subject.size() ){
 
         std::list< DBTREE::ArticleBase* >::iterator it;
-        for( it = list_subject.begin(); it != list_subject.end(); ++it, ++id ){
+        for( it = list_subject.begin(); it != list_subject.end(); ++it ){
 
             DBTREE::ArticleBase* art = *( it );
-    
-            // 行を作って内容をセット
-            Gtk::TreeModel::Row row = *( m_liststore->prepend() ); // append より prepend の方が速いらしい
 
-            row[ m_columns.m_col_id ]  = id;
-            row[ m_columns.m_col_since ] = art->get_since_date();
-
-            if( art->get_status() & STATUS_NORMAL )
-                row[ m_columns.m_col_speed ] = art->get_speed();
-        
-            row[ m_columns.m_col_since_t ] = art->get_since_time();
-            row[ m_columns.m_col_id_dat ] = art->get_id();
-
-            row[ m_columns.m_col_drawbg ] = false;
-
-            update_row_common( art, row );
-
-            // 更新があるかチェック
-            if( art->get_number_load() && art->get_number() > art->get_number_load() ) m_updated = true;
+            prepend_row( art );
         }
 
 #if GTKMMVER >= 280
         m_treeview.set_model( m_liststore );
 #endif
 
-        restore_sort();
+        if( m_list_draw_bg_articles.size() ) draw_bg_articles();
+        else restore_sort();
     }
 
     // ステータスバー更新
     std::ostringstream ss_tmp;
-    ss_tmp << DBTREE::board_str_code( get_url_board() ) << " [ 全 " << ( id -1 ) << " ] ";
+    ss_tmp << DBTREE::board_str_code( get_url_board() ) << " [ 全 " << m_id << " ] ";
     set_status( ss_tmp.str() );
     BOARD::get_admin()->set_command( "set_status", get_url(), get_status() );
 
@@ -1104,10 +1151,55 @@ const bool BoardViewBase::operate_view( const int control )
             BOARD::get_admin()->set_command( "tab_left" );
             break;
 
+        case CONTROL::TabLeftUpdated:
+            BOARD::get_admin()->set_command( "tab_left_updated" );
+            break;
+
         case CONTROL::TabRight:
             BOARD::get_admin()->set_command( "tab_right" );
             break;
 
+        case CONTROL::TabRightUpdated:
+            BOARD::get_admin()->set_command( "tab_right_updated" );
+            break;
+
+        // タブ位置(1-9)で移動
+        case CONTROL::TabNum1:
+            BOARD::get_admin()->set_command( "tab_num", "", "1" );
+            break;
+
+        case CONTROL::TabNum2:
+            BOARD::get_admin()->set_command( "tab_num", "", "2" );
+            break;
+
+        case CONTROL::TabNum3:
+            BOARD::get_admin()->set_command( "tab_num", "", "3" );
+            break;
+
+        case CONTROL::TabNum4:
+            BOARD::get_admin()->set_command( "tab_num", "", "4" );
+            break;
+
+        case CONTROL::TabNum5:
+            BOARD::get_admin()->set_command( "tab_num", "", "5" );
+            break;
+
+        case CONTROL::TabNum6:
+            BOARD::get_admin()->set_command( "tab_num", "", "6" );
+            break;
+
+        case CONTROL::TabNum7:
+            BOARD::get_admin()->set_command( "tab_num", "", "7" );
+            break;
+
+        case CONTROL::TabNum8:
+            BOARD::get_admin()->set_command( "tab_num", "", "8" );
+            break;
+
+        case CONTROL::TabNum9:
+            BOARD::get_admin()->set_command( "tab_num", "", "9" );
+            break;
+
             // 戻る、進む
         case CONTROL::PrevView:
             back_viewhistory( 1 );
@@ -1160,12 +1252,12 @@ const bool BoardViewBase::operate_view( const int control )
         // 検索
         case CONTROL::Search:
             m_search_invert = false;
-            BOARD::get_admin()->set_command( "focus_toolbar_search" );
+            BOARD::get_admin()->set_command( "open_searchbar", get_url() );
             break;
 
         case CONTROL::SearchInvert:
             m_search_invert = true;
-            BOARD::get_admin()->set_command( "focus_toolbar_search" );
+            BOARD::get_admin()->set_command( "open_searchbar", get_url() );
             break;
 
         case CONTROL::SearchNext:
@@ -1301,6 +1393,45 @@ void BoardViewBase::page_down()
 } 
    
 
+//
+// ポップアップメニューを表示する前にメニューのアクティブ状態を切り替える
+//
+// SKELETON::View::show_popupmenu() を参照すること
+//
+void BoardViewBase::activate_act_before_popupmenu( const std::string& url )
+{
+    // toggle　アクションを activeにするとスロット関数が呼ばれるので処理しないようにする
+    m_enable_menuslot = false;
+
+    Glib::RefPtr< Gtk::Action > act;
+
+    // dat 保存
+    act = action_group()->get_action( "SaveDat" );
+    if( act ){
+
+        act->set_sensitive( false );
+
+        std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
+        if( list_it.size() ){
+
+            std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
+            for( ; it != list_it.end(); ++it ){
+
+                Gtk::TreeModel::Row row = *( *it );
+                const std::string url = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
+
+                if( DBTREE::article_is_cached( url ) ) {
+                    act->set_sensitive( true );
+                    break;
+                }
+            }
+        }
+    }
+
+    m_enable_menuslot = true;
+}
+
+
 //
 // ポップアップメニュー取得
 //
@@ -1336,7 +1467,6 @@ Gtk::Menu* BoardViewBase::get_popupmenu( const std::string& url )
 }
 
 
-
 //
 // 特定の行だけの更新
 //
@@ -1348,31 +1478,48 @@ void BoardViewBase::update_item( const std::string& url, const std::string& id_d
     std::cout << "BoardViewBase::update_item " << get_url() << " id = " << id_dat << std::endl;
 #endif
 
-    Gtk::TreeModel::Children child = m_liststore->children();
-    Gtk::TreeModel::Children::iterator it;
-
     // 自動ソート抑制
     UNSORTED_COLUMN();
     
-    for( it = child.begin() ; it != child.end() ; ++it ){
+    Gtk::TreeModel::Row row = get_row_from_url( id_dat );
+    if( row ){
 
-        Gtk::TreeModel::Row row = *( it );
-        
-        // 対象の行なら内容更新
-        if( row[ m_columns.m_col_id_dat ] == id_dat ){
+        const std::string url_art = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
+        DBTREE::ArticleBase* art = DBTREE::get_article( url_art );
 
-            const std::string url = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
-            DBTREE::ArticleBase* art = DBTREE::get_article( url );
-
-            update_row_common( art, row );
-        }
+        update_row_common( art, row );
     }
 }
 
 
+//
+// 行を作って内容をセット
+//
+Gtk::TreeModel::Row BoardViewBase::prepend_row( DBTREE::ArticleBase* art )
+{
+    Gtk::TreeModel::Row row = *( m_liststore->prepend() ); // append より prepend の方が速いらしい
+
+    ++m_id;
+
+    row[ m_columns.m_col_id ]  = m_id;
+    row[ m_columns.m_col_since ] = art->get_since_date();
+
+    if( art->get_status() & STATUS_NORMAL )
+        row[ m_columns.m_col_speed ] = art->get_speed();
+        
+    row[ m_columns.m_col_since_t ] = art->get_since_time();
+    row[ m_columns.m_col_id_dat ] = art->get_id();
+
+    row[ m_columns.m_col_drawbg ] = false;
+
+    update_row_common( art, row );
+
+    return row;
+}
+
 
 //
-// update_view() と update_item() で共通に更新する列
+// prepend_row() と update_item() で共通に更新する列
 //
 void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel::Row& row )
 {
@@ -1413,16 +1560,25 @@ void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel:
     int mark_val;
     int icon;
 
-    // ブックマーク & 新着あり
-    if( art->is_bookmarked_thread() && art->enable_load() ){
-        mark_val = COL_MARKVAL_BKMARKED_UPDATED;
-        icon = ICON::BKMARK_UPDATE;
-    }
+    // ブックマーク 
+    if( art->is_bookmarked_thread() ){
 
-    // ブックマーク
-    else if( art->is_bookmarked_thread() ){
-        mark_val = COL_MARKVAL_BKMARKED;
-        icon = ICON::BKMARK;
+        //  新着あり
+        if( art->enable_load() ){
+            mark_val = COL_MARKVAL_BKMARKED_UPDATED;
+            icon = ICON::BKMARK_UPDATE;
+        }
+
+        // subject.txt が壊れている( subject.txt に示されたレス数よりも実際の取得数の方が多い )
+        else if( art->is_cached() && ( art->get_status() & STATUS_BROKEN_SUBJECT ) ){
+            mark_val = COL_MARKVAL_BKMARKED_BROKEN_SUBJECT;
+            icon = ICON::BKMARK_BROKEN_SUBJECT;
+        }
+
+        else{
+            mark_val = COL_MARKVAL_BKMARKED;
+            icon = ICON::BKMARK;
+        }
     }
 
     // dat落ち
@@ -1434,7 +1590,10 @@ void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel:
     // キャッシュはあるが規定のレス数を越えていて全てのレスが既読
     else if( art->is_finished() ){
         mark_val = COL_MARKVAL_FINISHED;
-        icon = ICON::CHECK;
+
+        // subject.txt が壊れている( subject.txt に示されたレス数よりも実際の取得数の方が多い )
+        if( art->get_status() & STATUS_BROKEN_SUBJECT ) icon = ICON::BROKEN_SUBJECT;
+        else icon = ICON::CHECK;
     }
 
     // 新着あり
@@ -1442,11 +1601,23 @@ void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel:
         mark_val = COL_MARKVAL_UPDATED;
         icon = ICON::UPDATE;
     }
-    // キャッシュあり、新着無し
+
+    // キャッシュあり
     else if( art->is_cached() ){
-        mark_val = COL_MARKVAL_CACHED;
-        icon = ICON::CHECK;
+
+        // subject.txt が壊れている( subject.txt に示されたレス数よりも実際の取得数の方が多い )
+        if( art->get_status() & STATUS_BROKEN_SUBJECT ){
+            mark_val = COL_MARKVAL_BROKEN_SUBJECT;
+            icon = ICON::BROKEN_SUBJECT;
+        }
+
+        // 新着無し
+        else{
+            mark_val = COL_MARKVAL_CACHED;
+            icon = ICON::CHECK;
+        }
     }
+
     // キャッシュ無し、新着
     else if( art->get_since_time() > m_last_access_time ){
         mark_val = COL_MARKVAL_NEWTHREAD;
@@ -1681,6 +1852,40 @@ void BoardViewBase::slot_drag_data_get( const Glib::RefPtr<Gdk::DragContext>& co
 }
 
 
+//
+// text/url-list がドロップされた
+//
+void BoardViewBase::slot_dropped_url_list( const std::list< std::string >& url_list )
+{
+#ifdef _DEBUG
+    std::cout << "BoardViewBase::slot_dropped_url_list\n";
+#endif
+
+    if( ! url_list.size() ) return;
+
+    // 共有バッファにアドレスをセットしてから import_dat コマンドを発行
+    CORE::DATA_INFO_LIST list_info;
+    std::list< std::string >::const_iterator it = url_list.begin();
+    for( ; it != url_list.end(); ++it ){
+
+        if( ( *it ).empty() ) continue;
+        if( ( *it ).find( "file://" ) == std::string::npos ) continue;
+
+        CORE::DATA_INFO info;
+        info.type = TYPE_FILE;
+        info.url = MISC::remove_str( ( *it ), "file://" );
+        list_info.push_back( info );
+
+#ifdef _DEBUG    
+        std::cout << "append " << info.url << std::endl;
+#endif
+    }
+
+    CORE::SBUF_set_list( list_info );
+    CORE::core_set_command( "import_dat", get_url_board(), "no_show_diag", "use_sbuf" );
+}
+
+
 //
 // ブックマーク設定、解除
 //
@@ -1787,11 +1992,8 @@ void BoardViewBase::slot_copy_title_url()
 
     const std::string url = DBTREE::url_readcgi( path2daturl( m_path_selected ), 0, 0 );
     const std::string name = DBTREE::article_subject( url );
-    std::stringstream ss;
-    ss << name << std::endl
-       << url << std::endl;
 
-    MISC::CopyClipboard( ss.str() );
+    MISC::CopyClipboard( name + '\n' + url );
 }
 
 
@@ -2097,10 +2299,131 @@ void BoardViewBase::forward_viewhistory( const int count )
 //
 void BoardViewBase::slot_save_dat()
 {
-    if( m_path_selected.empty() ) return;
-    const std::string url = path2daturl( m_path_selected );
+    if( ! m_enable_menuslot ) return;
+
+    std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
+    std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
+
+#ifdef _DEBUG
+    std::cout << "BoardViewBase::slot_save_dat size = " << list_it.size() << std::endl;
+#endif
+
+    if( ! list_it.size() ) return;
+
+    // ひとつだけ名前を付けて保存
+    if( list_it.size() == 1 ){
+
+        if( m_path_selected.empty() ) return;
+        const std::string url = path2daturl( m_path_selected );
+
+        DBTREE::article_save_dat( url, std::string() );
+        return;
+    }
+
+    // 複数のdatを保存
+
+    int overwrite = Gtk::RESPONSE_NO;
+
+    // ディレクトリ選択
+    SKELETON::FileDiag diag( get_parent_win(), "保存先選択", Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER );
+    diag.set_current_folder( SESSION::get_dir_dat() );
+    if( diag.run() != Gtk::RESPONSE_ACCEPT ) return;
+
+    diag.hide();
+
+    std::string path_dir = MISC::recover_path( diag.get_filename() );
+    if( path_dir.empty() ) return;
+    if( path_dir.c_str()[ path_dir.length()-1 ] != '/' ) path_dir += "/";
+        
+#ifdef _DEBUG
+    std::cout << "dir = " << path_dir << std::endl;
+#endif
+
+    if( ! CACHE::jdmkdir( path_dir ) ){
+
+        SKELETON::MsgDiag mdiag( get_parent_win(), path_dir + "\n\nの作成に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。\n\ndatファイルの保存をキャンセルしました。原因を解決してからもう一度保存を行ってください。" );
+        mdiag.run();
+        return;
+    }
+
+    SESSION::set_dir_dat( path_dir );
+
+    for( ; it != list_it.end(); ++it ){
+
+        Gtk::TreeModel::Row row = *( *it );
+        const std::string url = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
+
+        if( ! DBTREE::article_is_cached( url ) ) continue;
+
+        const std::string path_from = CACHE::path_dat( url );
+        const std::string path_to = path_dir + MISC::get_filename( url );
+
+#ifdef _DEBUG
+        std::cout << "from = " << path_from  << std::endl;
+        std::cout << "to   = " << path_to  << std::endl;
+#endif
+
+        bool copy_file = true;
+
+        // 既にファイルがある場合
+        if( CACHE::file_exists( path_to ) == CACHE::EXIST_FILE ){
+
+            // すべて上書き
+            if( overwrite == SKELETON::OVERWRITE_YES_ALL ) copy_file = true;
+
+            // すべていいえ
+            else if( overwrite == SKELETON::OVERWRITE_NO_ALL ) copy_file = false;
+
+            else{
+
+                for(;;){
+
+                    SKELETON::MsgOverwriteDiag mdiag( get_parent_win() );
+
+                    overwrite = mdiag.run();
+                    mdiag.hide();
+
+                    switch( overwrite ){
+
+                        // すべて上書き
+                        case SKELETON::OVERWRITE_YES_ALL:
+
+                            // 上書き
+                        case SKELETON::OVERWRITE_YES:
+
+                            copy_file = true;
+                            break;
+
+                            // 名前変更
+                        case Gtk::RESPONSE_YES:
+                            if( ! DBTREE::article_save_dat( url, path_to ) ) continue;
+
+                        default:
+                            copy_file = false;
+                            break;
+                    }
+
+                    break;  // for(;;)
+                }
+            }
+        }
+
+        if( copy_file ){
+
+#ifdef _DEBUG
+            std::cout << "copy\n";
+#endif
+            if( ! CACHE::jdcopy( path_from, path_to ) ){
+
+                SKELETON::MsgDiag mdiag( get_parent_win(), path_to + "\n\nの保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。\n\ndatファイルの保存をキャンセルしました。原因を解決してからもう一度保存を行ってください。" );
+                mdiag.run();
+
+                return;
+            }
+        }
+
+    }
 
-    DBTREE::article_save_dat( url, std::string() );
 }
 
 
@@ -2192,7 +2515,7 @@ void BoardViewBase::set_board_to_buffer()
     CORE::DATA_INFO_LIST list_info;
     CORE::DATA_INFO info;
     info.type = TYPE_BOARD;
-    info.url = get_url();
+    info.url = DBTREE::url_boardbase( get_url_board() );
     info.name = DBTREE::board_name( get_url_board() );
     info.data = std::string();
     info.path = Gtk::TreePath( "0" ).to_string();
@@ -2201,3 +2524,66 @@ void BoardViewBase::set_board_to_buffer()
 
     CORE::SBUF_set_list( list_info );
 }
+
+
+//
+// 指定したスレを強調して表示
+// dat 落ち等で表示されていないスレも強制的に表示する
+// 共有バッファに表示したいスレをセットしてから set_command 経由で呼び出す
+//
+void BoardViewBase::draw_bg_articles()
+{
+    // 共有バッファから追加するスレのURLのリストを作成
+    if( ! m_list_draw_bg_articles.size() ){
+
+        if( CORE::SBUF_size() == 0 ) return;
+
+        const CORE::DATA_INFO_LIST list_info = CORE::SBUF_list_info();
+        CORE::DATA_INFO_LIST::const_iterator it = list_info.begin();
+
+        for( ; it != list_info.end(); ++it ){
+
+            if( ( *it ).type != TYPE_THREAD ) continue;
+
+            m_list_draw_bg_articles.push_back( ( *it ).url );
+        }
+    }
+
+    if( ! m_list_draw_bg_articles.size() ) return;
+
+    // ロード中の時はロード後にもう一度呼び出す
+    if( is_loading() ) return;
+
+#ifdef _DEBUG
+    std::cout << "BoardViewBase::draw_bg_articles size = " << m_list_draw_bg_articles.size() << std::endl;
+#endif
+
+    // 自動ソート抑制
+    UNSORTED_COLUMN();
+
+    std::list< std::string >::const_iterator it = m_list_draw_bg_articles.begin();
+    for( ; it != m_list_draw_bg_articles.end(); ++it ){
+
+        const std::string& url = ( *it );
+
+#ifdef _DEBUG
+        std::cout << url << std::endl;
+#endif    
+
+        Gtk::TreeModel::Row row = get_row_from_url( url );
+
+        // row が無ければ作成
+        if( ! row ){
+            DBTREE::ArticleBase* art = DBTREE::get_article( url );
+            row = prepend_row( art );
+        }
+
+        // 強調表示
+        row[ m_columns.m_col_drawbg ] = true;
+    }
+
+    restore_sort();
+
+    m_list_draw_bg_articles.clear();
+}
+
