@@ -177,7 +177,7 @@ void Core::slot_toggle_toolbarpos( int pos )
     pack_widget( true );
 
     // 表示切り替え
-    if( SESSION::toolbar_pos() == pos ) pos = SESSION::TOOLBAR_NO;
+    if( SESSION::toolbar_pos() == pos ) pos = SESSION::TOOLBAR_POS_NOT;
     SESSION::set_toolbar_pos( pos );
 
     pack_widget( false );
@@ -350,8 +350,8 @@ void Core::slot_toggle_imgview( const int mode )
     else SESSION::set_embedded_img( false );
     pack_widget( false );
 
-    SESSION::set_focused_admin( SESSION::FOCUS_NO );
-    SESSION::set_focused_admin_sidebar( SESSION::FOCUS_NO );
+    SESSION::set_focused_admin( SESSION::FOCUS_NOT );
+    SESSION::set_focused_admin_sidebar( SESSION::FOCUS_NOT );
     restore_focus( true, false );
 }
 
@@ -388,9 +388,9 @@ void Core::slot_toggle_show_ssspicon()
 //
 // リスト項目(スレ一覧)の設定
 //
-void Core::slot_setup_boarditemcolumn()
+void Core::slot_setup_boarditem_column()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARDITEMCOLUM, "" );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARDITEM_COLUM, "" );
     pref->run();
     delete pref;
 }
@@ -451,6 +451,17 @@ void Core::slot_setup_msgitem()
 }
 
 
+//
+// コンテキストメニュー(スレビュー)の表示項目
+//
+void Core::slot_setup_articleitem_menu()
+{
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_ARTICLEITEM_MENU, "" );
+    pref->run();
+    delete pref;
+}
+
+
 //
 // スレ一覧のプロパティ
 //
@@ -642,6 +653,7 @@ void Core::slot_changefont_main()
     Gtk::FontSelectionDialog diag;
     diag.set_font_name( CONFIG::get_fontname( FONT_MAIN ) );
     diag.set_title( "スレビューフォント" );
+    diag.set_transient_for( *CORE::get_mainwindow() );
     if( diag.run() == Gtk::RESPONSE_OK ){
 
         CONFIG::set_fontname( FONT_MAIN, diag.get_font_name() );
@@ -662,6 +674,7 @@ void Core::slot_changefont_popup()
     Gtk::FontSelectionDialog diag;
     diag.set_font_name( CONFIG::get_fontname( FONT_POPUP ) );
     diag.set_title( "ポップアップフォント" );
+    diag.set_transient_for( *CORE::get_mainwindow() );
     if( diag.run() == Gtk::RESPONSE_OK ){
 
         CONFIG::set_fontname( FONT_POPUP, diag.get_font_name() );
@@ -678,6 +691,7 @@ void Core::slot_changefont_tree()
     Gtk::FontSelectionDialog diag;
     diag.set_font_name( CONFIG::get_fontname( FONT_BBS ) );
     diag.set_title( "板／スレ一覧フォント" );
+    diag.set_transient_for( *CORE::get_mainwindow() );
     if( diag.run() == Gtk::RESPONSE_OK ){
 
         CONFIG::set_fontname( FONT_BBS, diag.get_font_name() );
@@ -984,7 +998,7 @@ void Core::slot_search_title()
 
 
 //
-// お気に入りルートからの更新チェック( 通常 )
+// サイドバーの全更新チェック
 //
 void Core::slot_check_update_root()
 {
@@ -993,7 +1007,7 @@ void Core::slot_check_update_root()
 
 
 //
-// お気に入りルートからの更新チェック( タブで開く )
+// サイドバーを全更新チェックしてタブで開く
 //
 void Core::slot_check_update_open_root()
 {
