@@ -434,13 +434,52 @@ const bool MessageViewBase::operate_view( const int control )
             break;
 
         case CONTROL::TabLeft:
+        case CONTROL::TabLeftUpdated:
             MESSAGE::get_admin()->set_command( "tab_left" );
             break;
 
         case CONTROL::TabRight:
+        case CONTROL::TabRightUpdated:
             MESSAGE::get_admin()->set_command( "tab_right" );
             break;
 
+        // タブ位置(1-9)で移動
+        case CONTROL::TabNum1:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "1" );
+            break;
+
+        case CONTROL::TabNum2:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "2" );
+            break;
+
+        case CONTROL::TabNum3:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "3" );
+            break;
+
+        case CONTROL::TabNum4:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "4" );
+            break;
+
+        case CONTROL::TabNum5:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "5" );
+            break;
+
+        case CONTROL::TabNum6:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "6" );
+            break;
+
+        case CONTROL::TabNum7:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "7" );
+            break;
+
+        case CONTROL::TabNum8:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "8" );
+            break;
+
+        case CONTROL::TabNum9:
+            MESSAGE::get_admin()->set_command( "tab_num", "", "9" );
+            break;
+
             // 書き込みボタンにフォーカスを移す
         case CONTROL::FocusWrite:
             MESSAGE::get_admin()->set_command( "focus_button_write" );
@@ -743,15 +782,16 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
         // 名前 + トリップ
         if( ! m_entry_name.get_text().empty() ){
 
-            std::string name = MISC::html_escape( m_entry_name.get_text() );
+            const std::string name_field = m_entry_name.get_text();
+
+            const size_t trip_pos = name_field.find( "#", 0 );
+
+            const std::string name = MISC::html_escape( name_field.substr( 0, trip_pos ) );
 
             std::string trip;
-
-	    std::string::size_type i = name.find( "#" );
-            if( i != std::string::npos ){
-
-                trip = MISC::get_trip( name.substr( i+1 ), DBTREE::board_charset( get_url() ) );
-                name = name.substr( 0, i );
+            if( trip_pos != std::string::npos )
+            {
+                trip = MISC::get_trip( name_field.substr( trip_pos + 1 ), DBTREE::board_charset( get_url() ) );
             }
 
             ss << name;
